.. :changelog:

.. _KeepAChangelog: http://keepachangelog.com/
.. _SemanticVersioning: http://semver.org/

Change Log
----------

All notable changes to this project will be documented in this file.

The format is based on KeepAChangelog_ and this project adheres to SemanticVersioning_.

[Unreleased]
++++++++++++


[1.0.0] 2021-03-02
++++++++++++++++++

Added
~~~~~
* First release on PyPI.
